mailr7032 - in /1.3: generic_fns/ generic_fns/structure/ specific_fns/ specific_fns/model_free/


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on July 30, 2008 - 21:13:
Author: semor
Date: Wed Jul 30 20:39:37 2008
New Revision: 7032

URL: http://svn.gna.org/viewcvs/relax?rev=7032&view=rev
Log:
Converted run arguments to pipes.


Modified:
    1.3/generic_fns/dasha.py
    1.3/generic_fns/grace.py
    1.3/generic_fns/relax_data.py
    1.3/generic_fns/structure/geometric.py
    1.3/generic_fns/value.py
    1.3/specific_fns/consistency_tests.py
    1.3/specific_fns/hybrid.py
    1.3/specific_fns/jw_mapping.py
    1.3/specific_fns/model_free/main.py
    1.3/specific_fns/noe.py

Modified: 1.3/generic_fns/dasha.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/dasha.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/generic_fns/dasha.py (original)
+++ 1.3/generic_fns/dasha.py Wed Jul 30 20:39:37 2008
@@ -53,9 +53,9 @@
         self.dir = dir
         self.force = force
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if sequence data is loaded.
         if not ds.res.has_key(self.run):

Modified: 1.3/generic_fns/grace.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/grace.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/generic_fns/grace.py (original)
+++ 1.3/generic_fns/grace.py Wed Jul 30 20:39:37 2008
@@ -197,9 +197,9 @@
         self.plot_data = plot_data
         self.norm = norm
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the sequence data is loaded.
         if not exists_mol_res_spin_data():

Modified: 1.3/generic_fns/relax_data.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/relax_data.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/generic_fns/relax_data.py (original)
+++ 1.3/generic_fns/relax_data.py Wed Jul 30 20:39:37 2008
@@ -139,9 +139,9 @@
 def back_calc(ri_label=None, frq_label=None, frq=None):
     """Function for back calculating relaxation data."""
 
-    # Test if the run exists.
-    if not self.run in ds.run_names:
-        raise RelaxNoPipeError, self.run
+    # Test if the current pipe exists.
+    if not ds.current_pipe:
+        raise RelaxNoPipeError
 
     # Test if sequence data is loaded.
     if not ds.res.has_key(self.run):
@@ -407,9 +407,9 @@
     self.ri_label = ri_label
     self.frq_label = frq_label
 
-    # Test if the run exists.
-    if not self.run in ds.run_names:
-        raise RelaxNoPipeError, self.run
+    # Test if the current pipe exists.
+    if not ds.current_pipe:
+        raise RelaxNoPipeError
 
     # Test if the sequence data is loaded.
     if not ds.res.has_key(self.run):
@@ -477,9 +477,9 @@
     self.ri_label = ri_label
     self.frq_label = frq_label
 
-    # Test if the run exists.
-    if not self.run in ds.run_names:
-        raise RelaxNoPipeError, self.run
+    # Test if the current pipe exists.
+    if not ds.current_pipe:
+        raise RelaxNoPipeError
 
     # Test if the sequence data is loaded.
     if not ds.res.has_key(self.run):
@@ -912,9 +912,9 @@
     self.ri_label = ri_label
     self.frq_label = frq_label
 
-    # Test if the run exists.
-    if not self.run in ds.run_names:
-        raise RelaxNoPipeError, self.run
+    # Test if the current pipe exists.
+    if not ds.current_pipe:
+        raise RelaxNoPipeError
 
     # Test if the sequence data is loaded.
     if not ds.res.has_key(self.run):

Modified: 1.3/generic_fns/structure/geometric.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/structure/geometric.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/generic_fns/structure/geometric.py (original)
+++ 1.3/generic_fns/structure/geometric.py Wed Jul 30 20:39:37 2008
@@ -322,9 +322,9 @@
     # Arguments.
     run = run
 
-    # Test if the run exists.
-    if not run in ds.run_names:
-        raise RelaxNoPipeError, run
+    # Test if the current pipe exists.
+    if not ds.current_pipe:
+        raise RelaxNoPipeError
 
     # Test if the PDB file of the macromolecule has been loaded.
     if not ds.pdb.has_key(run):

Modified: 1.3/generic_fns/value.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/value.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/generic_fns/value.py (original)
+++ 1.3/generic_fns/value.py Wed Jul 30 20:39:37 2008
@@ -394,9 +394,9 @@
         self.run = run
         self.param = param
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the sequence data is loaded.
         if not ds.res.has_key(self.run):
@@ -414,9 +414,9 @@
         self.param = param
         self.scaling = scaling
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if sequence data is loaded.
         if not ds.res.has_key(self.run):
@@ -568,9 +568,9 @@
         self.run = run
         self.param = param
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the sequence data is loaded.
         if not ds.res.has_key(self.run):

Modified: 1.3/specific_fns/consistency_tests.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/consistency_tests.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/specific_fns/consistency_tests.py (original)
+++ 1.3/specific_fns/consistency_tests.py Wed Jul 30 20:39:37 2008
@@ -584,9 +584,9 @@
         # Alias the current data pipe.
         cdp = ds[ds.current_pipe]
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if sequence data is loaded.
         if not exists_mol_res_spin_data():

Modified: 1.3/specific_fns/hybrid.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/hybrid.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/specific_fns/hybrid.py (original)
+++ 1.3/specific_fns/hybrid.py Wed Jul 30 20:39:37 2008
@@ -61,9 +61,9 @@
 
         # Loop over the runs to be hybridised.
         for run in runs:
-            # Test if the run exists.
-            if not run in ds.run_names:
-                raise RelaxNoPipeError, run
+            # Test if the current pipe exists.
+            if not ds.current_pipe:
+                raise RelaxNoPipeError
 
             # Test if sequence data is loaded.
             if not ds.res.has_key(run):

Modified: 1.3/specific_fns/jw_mapping.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/jw_mapping.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/specific_fns/jw_mapping.py (original)
+++ 1.3/specific_fns/jw_mapping.py Wed Jul 30 20:39:37 2008
@@ -524,9 +524,9 @@
         # Alias the current data pipe.
         cdp = ds[ds.current_pipe]
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if sequence data is loaded.
         if not exists_mol_res_spin_data():

Modified: 1.3/specific_fns/model_free/main.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/model_free/main.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/specific_fns/model_free/main.py (original)
+++ 1.3/specific_fns/model_free/main.py Wed Jul 30 20:39:37 2008
@@ -841,9 +841,9 @@
         # Arguments.
         self.run = run
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the run type is set to 'mf'.
         function_type = ds.run_types[ds.run_names.index(self.run)]

Modified: 1.3/specific_fns/noe.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/noe.py?rev=7032&r1=7031&r2=7032&view=diff
==============================================================================
--- 1.3/specific_fns/noe.py (original)
+++ 1.3/specific_fns/noe.py Wed Jul 30 20:39:37 2008
@@ -57,9 +57,9 @@
         # Arguments.
         self.run = run
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Loop over the sequence.
         for i in xrange(len(ds.res[self.run])):
@@ -329,9 +329,9 @@
         self.res_num = res_num
         self.res_name = res_name
 
-        # Test if the run exists.
-        if not run in ds.run_names:
-            raise RelaxNoPipeError, run
+        # Test if the current pipe exists
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the sequence data is loaded.
         if not ds.res.has_key(run):
@@ -383,9 +383,9 @@
         # Arguments
         self.run = run
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the sequence data is loaded.
         if not ds.res.has_key(self.run):
@@ -430,9 +430,9 @@
         # Arguments.
         self.run = run
 
-        # Test if the run exists.
-        if not self.run in ds.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not ds.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if sequence data is loaded.
         if not ds.res.has_key(self.run):




Related Messages


Powered by MHonArc, Updated Wed Jul 30 22:20:22 2008